@@ -1,8 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import argparse
 import io
 import re
@@ -66,12 +62,12 @@ def pretty_format_yaml(argv: typing.Optional[typing.List[str]] = None) -> int:
     yaml.indent = args.indent
     yaml.preserve_quotes = args.preserve_quotes
     # Prevent ruamel.yaml to wrap yaml lines
-    yaml.width = maxsize
+    yaml.width = maxsize  # type: ignore  # mypy recognise yaml.width as None
 
     separator = "---\n"
 
     for yaml_file in set(args.filenames):
-        with open(yaml_file) as input_file:
+        with open(yaml_file, encoding="utf8") as input_file:
             string_content = "".join(input_file.readlines())
 
         # Split multi-document file into individual documents
